@@ -1604,6 +1604,14 @@ public:
          * @return number of linear audio samples written to file.
          */
 	unsigned bufStereo(Linear Buffer, unsigned samples);
+
+	/**
+	 * Return the codec being used if there is one.
+	 *
+	 * @return codec used.
+	 */
+	inline AudioCodec *getCodec(void)
+		{return codec;};
 };
 
 /**
