@@ -172,6 +172,9 @@ void Tool::info(char **argv)
 		snprintf(duration, sizeof(duration), 
 			"%02d:%02d:%02d.%03d", end, minutes, seconds, subsec);
 		cout << "    Total Duration: " << duration << endl;
+
+		if(info.headersize)
+			cout << "    Computed Frame Size: " << info.framesize - info.headersize - info.padding << ", header=" << info.headersize << ", padding=" << info.padding << endl;    
 		
 		au.close();
 	}
